==> jc-1.4.0.tar.gz: polyglot/main/UsageError.h <==
// public class polyglot.main.UsageError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class b03d8bfb90ecee8b polyglot_main_UsageError

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_polyglot_main_UsageError_H_
#define _JC_polyglot_main_UsageError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_main_UsageError$sub_refs	_jc_polyglot_main_UsageError$sub_refs;
typedef struct _jc_polyglot_main_UsageError$sub_nonrefs	_jc_polyglot_main_UsageError$sub_nonrefs;
typedef struct _jc_polyglot_main_UsageError$refs	_jc_polyglot_main_UsageError$refs;
typedef struct _jc_polyglot_main_UsageError$nonrefs	_jc_polyglot_main_UsageError$nonrefs;
typedef struct _jc_polyglot_main_UsageError$object	_jc_polyglot_main_UsageError$object;

typedef const struct _jc_polyglot_main_UsageError$vmethods	_jc_polyglot_main_UsageError$vmethods;
typedef const struct _jc_polyglot_main_UsageError$vtable	_jc_polyglot_main_UsageError$vtable;
typedef const struct _jc_polyglot_main_UsageError$vtype	_jc_polyglot_main_UsageError$vtype;

// Constructors
extern void _jc_polyglot_main_UsageError$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_main_UsageError$object *, struct _jc_java_lang_String$object *);
extern void _jc_polyglot_main_UsageError$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_polyglot_main_UsageError$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods structure
struct _jc_polyglot_main_UsageError$vmethods {
};

// Vtable
struct _jc_polyglot_main_UsageError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_polyglot_main_UsageError$vmethods	polyglot_main_UsageError;
};

// Vtype
struct _jc_polyglot_main_UsageError$vtype {
	_jc_type			type;
	_jc_polyglot_main_UsageError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_main_UsageError$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_main_UsageError$refs {
    _jc_polyglot_main_UsageError$sub_refs	polyglot_main_UsageError;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_main_UsageError$sub_nonrefs {
	jint	exitCode;
};

// Non-reference instance fields (object)
struct _jc_polyglot_main_UsageError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_polyglot_main_UsageError$sub_nonrefs	polyglot_main_UsageError;
};

// Object instance structure
struct _jc_polyglot_main_UsageError$object {
	_jc_polyglot_main_UsageError$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_main_UsageError$vtype	*vtype;
	_jc_polyglot_main_UsageError$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_main_UsageError$vtype _jc_polyglot_main_UsageError$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_main_UsageError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_main_UsageError$class_object;

#endif	/* _JC_polyglot_main_UsageError_H_ */

==> jc-1.4.6.tar.gz: polyglot/main/UsageError.h <==
// public class polyglot.main.UsageError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class b03d8bfb90ecee8b polyglot_main_UsageError

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_polyglot_main_UsageError_H_
#define _JC_polyglot_main_UsageError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_main_UsageError$sub_refs	_jc_polyglot_main_UsageError$sub_refs;
typedef struct _jc_polyglot_main_UsageError$sub_nonrefs	_jc_polyglot_main_UsageError$sub_nonrefs;
typedef struct _jc_polyglot_main_UsageError$refs	_jc_polyglot_main_UsageError$refs;
typedef struct _jc_polyglot_main_UsageError$nonrefs	_jc_polyglot_main_UsageError$nonrefs;
typedef struct _jc_polyglot_main_UsageError$object	_jc_polyglot_main_UsageError$object;

typedef const struct _jc_polyglot_main_UsageError$vmethods	_jc_polyglot_main_UsageError$vmethods;
typedef const struct _jc_polyglot_main_UsageError$vtable	_jc_polyglot_main_UsageError$vtable;
typedef const struct _jc_polyglot_main_UsageError$vtype	_jc_polyglot_main_UsageError$vtype;

// Constructors
extern void _jc_polyglot_main_UsageError$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_main_UsageError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_main_UsageError$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_polyglot_main_UsageError$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_main_UsageError$vmethods {
};

// Vtable
struct _jc_polyglot_main_UsageError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_polyglot_main_UsageError$vmethods	polyglot_main_UsageError;
};

// Vtype
struct _jc_polyglot_main_UsageError$vtype {
	_jc_type			type;
	_jc_polyglot_main_UsageError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_main_UsageError$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_main_UsageError$refs {
    _jc_polyglot_main_UsageError$sub_refs	polyglot_main_UsageError;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_main_UsageError$sub_nonrefs {
	jint	exitCode;
};

// Non-reference instance fields (object)
struct _jc_polyglot_main_UsageError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_polyglot_main_UsageError$sub_nonrefs	polyglot_main_UsageError;
};

// Object instance structure
struct _jc_polyglot_main_UsageError$object {
	_jc_polyglot_main_UsageError$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_main_UsageError$vtype	*vtype;
	_jc_polyglot_main_UsageError$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_main_UsageError$vtype _jc_polyglot_main_UsageError$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_main_UsageError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_main_UsageError$class_object;

#endif	/* _JC_polyglot_main_UsageError_H_ */
